# -*- coding: utf-8 -*-
#
# Copyright (C) 2025 California Institute of Technology.
#
# Invenio-RDM is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Tests for communities module."""
